@@ -12,7 +12,7 @@ use Aspect::Advice        ();
 use Aspect::Advice::Hook  ();
 use Aspect::AdviceContext ();
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -29,7 +29,7 @@ sub _install {
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
 	my $curried   = $pointcut->curry_run;
-	my $MATCH_RUN = $curried ? '$curried->match_run($name, $runtime)' : 1;
+	my $MATCH_RUN = $curried ? '$curried->match_run($runtime)' : 1;
 
 	# When an aspect falls out of scope, we don't attempt to remove
 	# the generated hook code, because it might (for reasons potentially
@@ -77,6 +77,7 @@ sub _install {
 				] };
 
 				my \$runtime = {
+					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					return_value => \$return,
 					exception    => \$\@,
@@ -90,7 +91,6 @@ sub _install {
 				my \$context = Aspect::AdviceContext->new(
 					type     => 'after',
 					pointcut => \$pointcut,
-					sub_name => \$name,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
@@ -104,12 +104,7 @@ sub _install {
 				die \$exception if \$exception;
 
 				# Get the (potentially) modified return value
-				\$return = \$context->return_value;
-				if ( ref \$return eq 'ARRAY' ) {
-					return \@\$return;
-				} else {
-					return ( \$return );
-				}
+				return \@{\$context->{return_value}};
 			}
 
 			if ( defined \$wantarray ) {
@@ -120,6 +115,7 @@ sub _install {
 				};
 
 				my \$runtime = {
+					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					return_value => \$return,
 					exception    => \$\@,
@@ -133,7 +129,6 @@ sub _install {
 				my \$context = Aspect::AdviceContext->new(
 					type     => 'after',
 					pointcut => \$pointcut,
-					sub_name => \$name,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
@@ -147,7 +142,7 @@ sub _install {
 				die \$exception if \$exception;
 
 				# Return the potentially-modified value
-				return \$context->return_value;
+				return \$context->{return_value};
 
 			} else {
 				eval {
@@ -157,6 +152,7 @@ sub _install {
 				};
 
 				my \$runtime = {
+					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					return_value => undef,
 					exception    => \$\@,
@@ -170,7 +166,6 @@ sub _install {
 				my \$context = Aspect::AdviceContext->new(
 					type     => 'after',
 					pointcut => \$pointcut,
-					sub_name => \$name,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
