@@ -6,7 +6,7 @@ use Carp             ();
 use Params::Util     ('_STRING', '_INSTANCE');
 use Aspect::Pointcut ();
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -35,7 +35,8 @@ sub curry_run {
 # Runtime Methods
 
 sub match_run {
-	my ($self, undef, $runtime) = @_;
+	my $self    = shift;
+	my $runtime = shift;
 	unless ( exists $runtime->{exception} ) {
 		# We are not in an exception
 		return 0;
