@@ -5,7 +5,7 @@ use warnings;
 use Carp             ();
 use Aspect::Pointcut ();
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 our @ISA     = 'Aspect::Pointcut';
 
 use constant VOID   => 1;
@@ -51,7 +51,8 @@ sub curry_run {
 # Runtime Methods
 
 sub match_run {
-	my ($self, undef, $runtime) = @_;
+	my $self    = shift;
+	my $runtime = shift;
 	unless ( exists $runtime->{wantarray} ) {
 		Carp::croak("The wantarray field in the runtime state does not exist");
 	}
